@@ -21,7 +21,6 @@
 */
 
 #include <config.h>
-#include <unicode.h>
 #include "htmlcursor.h"
 #include "htmlengine.h"
 #include "htmlinterval.h"
@@ -150,7 +149,9 @@ select_object (HTMLObject *o, HTMLEngine *e, gpointer data)
 	if (o == i->from.object)
 		etop->selected_in = TRUE;
 	if (etop->selected_in)
-		html_object_select_range (o, e, html_interval_get_start (i, o), html_interval_get_length (i, o), TRUE);
+		html_object_select_range (o, e,
+					  html_interval_get_start (i, o), html_interval_get_length (i, o),
+					  !html_engine_frozen (e));
 
 	if (o == i->to.object)
 		etop->selected_in = FALSE;
@@ -160,13 +161,15 @@ void
 html_interval_select (HTMLInterval *i, HTMLEngine *e)
 {
 	html_engine_get_top_html_engine (e)->selected_in = FALSE;
+	i = html_interval_flat (i);
 	html_interval_forall (i, e, select_object, i);
+	html_interval_destroy (i);
 }
 
 static void
 unselect_object (HTMLObject *o, HTMLEngine *e, gpointer data)
 {
-	html_object_select_range (o, e, 0, 0, TRUE);
+	html_object_select_range (o, e, 0, 0, !html_engine_frozen (e));
 }
 
 void
@@ -257,7 +260,7 @@ html_interval_dup (HTMLInterval *i)
 	return html_interval_new_from_points (&i->from, &i->to);
 }
 
-static HTMLInterval *
+HTMLInterval *
 html_interval_flat (HTMLInterval *i)
 {
 	HTMLInterval *ni = html_interval_dup (i);
